@@ -34,6 +34,10 @@ class JMan:
     def pobles(self):
         return accions.Pobles(con=self._con)
 
+    @property
+    def provincies(self):
+        return accions.Provincies(con=self._con)
+
     @property
     def comandes(self):
         return accions.Comandes(con=self._con)
